==> ejc-zjkjcost-impl-3.0.0-20230420.113919-139-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeGrantEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
/**
 * 节点考核-节点目标奖金考核发放
 *
 * @author generator
 *
 */
 @TableName("ejc_zjkjcost_node_grant")
public class NodeGrantEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="distribution_mny")
    private BigDecimal distributionMny; // 分配金额
    @TableField(value="actual_mny")
    private BigDecimal actualMny; // 实发金额
    @TableField(value="node_approval_id")
    private Long nodeApprovalId; // 工程项目节点目标奖金审批id
    @TableField(value="node_approval_code")
    private String nodeApprovalCode; // 工程项目节点目标奖金审批单号

    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额


    @TableField(exist = false)
    @SubEntity(serviceName = "nodeGrantDetailService", pidName = "grantId")//此处有pid="xxx"，默认值pid="pid"
    private List<NodeGrantDetailEntity> nodeGrantDetailList = new ArrayList<>(); // 节点考核-节点目标奖金考核发放-明细


    public Long getNodeApprovalId() {
        return nodeApprovalId;
    }

    public void setNodeApprovalId(Long nodeApprovalId) {
        this.nodeApprovalId = nodeApprovalId;
    }

    public String getNodeApprovalCode() {
        return nodeApprovalCode;
    }

    public void setNodeApprovalCode(String nodeApprovalCode) {
        this.nodeApprovalCode = nodeApprovalCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getDistributionMny() {
        return distributionMny;
    }

    public void setDistributionMny(BigDecimal distributionMny) {
        this.distributionMny = distributionMny;
    }
    public BigDecimal getActualMny() {
        return actualMny;
    }

    public void setActualMny(BigDecimal actualMny) {
        this.actualMny = actualMny;
    }

    public List<NodeGrantDetailEntity> getNodeGrantDetailList() {
        return nodeGrantDetailList;
    }

    public void setNodeGrantDetailList(List<NodeGrantDetailEntity> nodeGrantDetailList) {
        this.nodeGrantDetailList = nodeGrantDetailList;
    }

    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
}

==> ejc-zjkjcost-impl-3.0.0-20230614.102201-179-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeGrantEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
/**
 * 节点考核-节点目标奖金考核发放
 *
 * @author generator
 *
 */
 @TableName("ejc_zjkjcost_node_grant")
public class NodeGrantEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="distribution_mny")
    private BigDecimal distributionMny; // 分配金额
    @TableField(value="actual_mny")
    private BigDecimal actualMny; // 实发金额
    @TableField(value="node_approval_id")
    private Long nodeApprovalId; // 工程项目节点目标奖金审批id
    @TableField(value="node_approval_code")
    private String nodeApprovalCode; // 工程项目节点目标奖金审批单号

    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额
    @TableField(value="project_status")
    private String projectStatus;  // 项目状态：1-未开工, 2-在建，3-完工，4-停缓建， 5-竣工未结算， 6-竣工已结算

    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }


    @TableField(exist = false)
    @SubEntity(serviceName = "nodeGrantDetailService", pidName = "grantId")//此处有pid="xxx"，默认值pid="pid"
    private List<NodeGrantDetailEntity> nodeGrantDetailList = new ArrayList<>(); // 节点考核-节点目标奖金考核发放-明细


    public Long getNodeApprovalId() {
        return nodeApprovalId;
    }

    public void setNodeApprovalId(Long nodeApprovalId) {
        this.nodeApprovalId = nodeApprovalId;
    }

    public String getNodeApprovalCode() {
        return nodeApprovalCode;
    }

    public void setNodeApprovalCode(String nodeApprovalCode) {
        this.nodeApprovalCode = nodeApprovalCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getDistributionMny() {
        return distributionMny;
    }

    public void setDistributionMny(BigDecimal distributionMny) {
        this.distributionMny = distributionMny;
    }
    public BigDecimal getActualMny() {
        return actualMny;
    }

    public void setActualMny(BigDecimal actualMny) {
        this.actualMny = actualMny;
    }

    public List<NodeGrantDetailEntity> getNodeGrantDetailList() {
        return nodeGrantDetailList;
    }

    public void setNodeGrantDetailList(List<NodeGrantDetailEntity> nodeGrantDetailList) {
        this.nodeGrantDetailList = nodeGrantDetailList;
    }

    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
}
